::: spotify.api.API
    options:
      members:
        - get_show
        - get_several_shows
        - get_show_episodes
        - get_users_saved_shows
        - save_shows_for_user
        - remove_users_saved_shows
        - check_users_saved_shows
::: spotify.models.SimpleShow
::: spotify.models.Show
::: spotify.models.SavedShow
